from setuptools import setup

setup(
    name='catcatfox777',
    version='0.1',
    author='foxcatio',
    author_email='mikerinkosta8@gmail.com',
    description='My package description',
    packages=['mytest'],
    install_requires=[
        'numpy',
        'pandas'
    ]
)